# Changelog


## [0.0.3] - YYYY-MM-DD

### Added
- Support for pages with no `body_text`.
- Added tests.

## [0.0.2] - 2025-05-14

### Added
- Initial release of `langchain-advertools`.
- `WebsiteLoader` class to load website crawl data from a JSONL file (generated by `advertools`) into LangChain `Document` objects.
- Support for both eager loading with `load()` and lazy loading with `lazy_load()`.
